@@ -1,6 +1,6 @@
 `EcosystemProduction.20` <- function (velocity, meandepth, temperature, DO, day, startday = 00:00:00, endday = 23:45:00, sunrise.time, sunset.time, num.readings){
-    require(zoo)
-    require(chron)
+    #require(zoo)
+    #require(chron)
     K <- ODobbins(velocity, meandepth)
     Ktemp <- Kt(K, temperature)
     Rearation.Flux <- rear.flux(DO, Ktemp, temperature, num.readings)
@@ -24,4 +24,4 @@
     P.R <- GPP/abs.CR24
     Units <- "gO/squared meters/d"
     metabolism <- cbind(CR24, NDM, abs.CR24, GPP, P.R, Units)
-}
\ No newline at end of file
+}
