@@ -1,7 +1,7 @@
 `EcosystemProduction.K` <- function (K, meandepth ,temperature, DO, day, startday = 00:00:00, endday = 23:45:00, sunrise.time, sunset.time, num.readings) 
 {
-    require(zoo)
-    require(chron)
+    #require(zoo)
+    #require(chron)
     Ktemp <- Kt(K, temperature)
     Rearation.Flux <- rear.flux(DO, Ktemp, temperature, num.readings)
     respiration.sr <- window.chron(Rearation.Flux, day, startday, 
