@@ -1,3 +1,3 @@
-'read.production' <- function(data){
+`read.production` <- function(data){
 	read.zoo(data, sep=",", FUN=fmt.chron, header=TRUE)
 	}
\ No newline at end of file
